package Catmandu::Activiti;
our $VERSION = "0.11";

=head1 NAME

Catmandu::Activiti - set of Catmandu modules for activiti

=head1 MODULES

L<Catmandu::Importer::Activiti::RuntimeProcessInstance>

L<Catmandu::Importer::Activiti::HistoricProcessInstance>

L<Catmandu::Importer::Activiti::RuntimeTask>

L<Catmandu::Importer::Activiti::HistoricTask>

=head1 SEE ALSO

L<Catmandu::Iterable>

http://www.activiti.org/userguide/

=head1 AUTHOR

Nicolas Franck C<< Nicolas Franck at UGent be >>

=cut

1;
